@@ -5,7 +5,7 @@ use warnings;
 package Tie::Reduce;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 ## suppresses warnings
 
@@ -178,11 +178,13 @@ people wishing to subclass this module.
 
 Constructor.
 
+This is called by C<< TIESCALAR >>.
+
 =item C<< tied($scalar)->get_value >>
 
 Returns the current value of the scalar variable.
 
-This is called by 
+This is called by C<< FETCH >>.
 
 =item C<< tied($scalar)->set_value($value) >>
 
@@ -196,6 +198,8 @@ Subclassers should be aware that this method uses C<caller> to find the
 name of the calling package and access package variables C<< $a >> and
 C<< $b >>.
 
+This is called by C<< STORE >>.
+
 =item C<< tied($scalar)->get_coderef >>
 
 Returns the coderef being used to reduce values.
